@@ -105,7 +105,7 @@ def predecir_clasificacion_binaria(model, X=None, umbral=0.5):
     
     y_pred_uno = np.where(y_prob_uno >= umbral, 1, 0).tolist()
     print("fin  predecir_clasificacion_binaria")
-    return y_pred_uno, y_prob_uno , predicted_probas
+    return y_pred_uno, y_prob_uno
 
 
 
